/***********************************************************************
 *
 * Copyright (C) 2008 Graeme Gott <graeme@gottcode.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#ifndef DATA_MODEL_H
#define DATA_MODEL_H

#include <QAbstractTableModel>
#include <QDateTime>
#include <QXmlStreamWriter>

class DataModel : public QAbstractTableModel {
public:
	DataModel(QObject* parent = 0);

	QDate date(int pos) const  {
		Q_ASSERT(pos < m_data.count());
		return m_data.at(pos).date;
	}

	QTime start(int pos) const {
		Q_ASSERT(pos < m_data.count());
		return m_data.at(pos).start;
	}

	QTime stop(int pos) const {
		Q_ASSERT(pos < m_data.count());
		return m_data.at(pos).stop;
	}

	bool isBilled(int pos) const {
		return (!m_billed.isEmpty() && pos <= m_billed.last());
	}

	bool add(const QDateTime& start, const QDateTime& stop, bool billed = false);
	bool edit(int row, const QDateTime& start, const QDateTime& stop);
	bool remove(int row);
	void setBilled(int row, bool billed);
	void toXml(QXmlStreamWriter& xml) const;

	virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
	virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
	virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
	virtual Qt::ItemFlags flags(const QModelIndex& index) const;
	virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
	virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);

private:
	void updateTotals();

private:
	struct Session {
		QDate date;
		QTime start;
		QTime stop;
		int daily;
		int weekly;
		int monthly;
		bool billed;
	};
	QList<Session> m_data;
	QList<int> m_billed;
};

#endif
