/***********************************************************************
 *
 * Copyright (C) 2008 Graeme Gott <graeme@gottcode.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "session_dialog.h"

#include <QDateEdit>
#include <QDialogButtonBox>
#include <QGridLayout>
#include <QLabel>
#include <QTimeEdit>

/*****************************************************************************/

SessionDialog::SessionDialog(QWidget* parent, const QDate& date, const QTime& start,  const QTime& stop)
: QDialog(parent) {
	m_date = new QDateEdit(this);
	m_date->setCalendarPopup(true);
	m_date->setDate(date.isValid() ? date : QDate::currentDate());

	m_start = new QTimeEdit(this);
	m_start->setTime(start.isValid() ? start : QTime::currentTime());
	m_start->setDisplayFormat("h:mm:ss AP");

	m_stop = new QTimeEdit(this);
	m_stop->setTime(stop.isValid() ? stop : QTime::currentTime());
	m_stop->setDisplayFormat("h:mm:ss AP");

	QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, this);
	connect(buttons, SIGNAL(accepted()), this, SLOT(accept()));
	connect(buttons, SIGNAL(rejected()), this, SLOT(reject()));

	QGridLayout* layout = new QGridLayout(this);
	layout->setMargin(12);
	layout->setSpacing(6);
	layout->setColumnStretch(0, 1);
	layout->setColumnStretch(4, 1);
	layout->setRowMinimumHeight(3, 18);
	layout->addWidget(new QLabel(tr("Date:"), this), 0, 1, Qt::AlignRight | Qt::AlignVCenter);
	layout->addWidget(m_date, 0, 3);
	layout->addWidget(new QLabel(tr("Start:"), this), 1, 1, Qt::AlignRight | Qt::AlignVCenter);
	layout->addWidget(m_start, 1, 3);
	layout->addWidget(new QLabel(tr("Stop:"), this), 2, 1, Qt::AlignRight | Qt::AlignVCenter);
	layout->addWidget(m_stop, 2, 3);
	layout->addWidget(buttons, 4, 0, 1, 5);
}

/*****************************************************************************/
